@@ -1,6 +1,8 @@
 import requests
 import json
 from datetime import datetime
+import numpy as np
+import os
 
 
 class GatewayClient:
@@ -204,3 +206,53 @@ class GatewayClient:
                 print("Exception: ", e)
         else:
             raise Exception("Client not authenticated")
+
+    def send_bulk_email(self, body: str, setting_id: str, recipients: list, subject: str, scheduled: bool = False, process_at: datetime = None):
+        """
+        Send Bulk Emails
+
+        :param recipients: List of email recipients
+        :param body: Message to be send
+        :param setting_id: ID of the specific email configuration to be used
+        :param subject: Subject of the email
+        :param scheduled: Where or not the email has to be sent at a later time
+        :param process_at: Time to process the email if it has been scheduled
+        :return: Response as Json
+        """
+        if self.__authenticated:
+            try:
+                url = f"{self.__host}/mailing/email/bulk/"
+
+                the_string = "email\r\n"
+                for email in recipients:
+                    the_string += f"{email}\r\n"
+
+                payload = {
+                    "body": body,
+                    "setting": setting_id,
+                    "subject": subject
+                }
+
+                if scheduled:
+                    assert process_at is not None
+                    payload["scheduled"] = scheduled
+                    payload["process_at"] = process_at
+
+                print("The String: \n", the_string)
+
+                self.axios.headers.pop("Content-Type")
+                response = self.axios.post(url, data=payload, files=[("csv", ("data.csv", the_string, "text/csv"))])
+                self.axios.headers.update({"Content-Type": "application/json"})
+
+                if response.status_code == 200:
+                    print("Email sent!")
+                    return response.json()
+                else:
+                    print("Failed to process request")
+                    print("Response: ", response.text)
+                    return response.json()
+            except Exception as e:
+                print("Failed to process request")
+                print("Exception: ", e)
+        else:
+            raise Exception("Client not authenticated")
